#' altair: Create and embed Vega-Lite charts using the Altair Python package
#'
#' The goal of altair is to help you build
#' [Vega-Lite](https://vega.github.io/vega-lite/) visualizations. Using the
#' [reticulate](https://rstudio.github.io/reticulate/) package, it provides
#' an interface to the [Altair](https://altair-viz.github.io) Python package.
#'
#' In this documentation, the capitalized word **Altair** shall refer to the
#' Python package; the lower-case word **altair** shall refer to this R package.
#'
#' @seealso
#'   [altair pkgdown website](https://vegawidget.github.io/altair/),
#'   [Altair Python package](https://altair-viz.github.io/index.html),
#'   [Vega-Lite](https://vega.github.io/vega-lite/)
#'
#' @keywords internal
"_PACKAGE"
